@@ -415,6 +415,8 @@ static void feh_parse_option_array(int argc, char **argv, int finalrun)
 		{"insecure"      , 0, 0, 240},
 		{"no-recursive"  , 0, 0, 241},
 		{"cache-size"    , 1, 0, 243},
+		{"version-sort"  , 0, 0, 246},
+		{"offset"        , 1, 0, 247},
 		{0, 0, 0, 0}
 	};
 	int optch = 0, cmdx = 0;
@@ -433,6 +435,7 @@ static void feh_parse_option_array(int argc, char **argv, int finalrun)
 			opt.debug = 1;
 			break;
 		case '<':
+			opt.filter_by_dimensions = 1;
 			XParseGeometry(optarg, &discard, &discard, &opt.max_width, &opt.max_height);
 			if (opt.max_width == 0)
 				opt.max_width = UINT_MAX;
@@ -440,6 +443,7 @@ static void feh_parse_option_array(int argc, char **argv, int finalrun)
 				opt.max_height = UINT_MAX;
 			break;
 		case '>':
+			opt.filter_by_dimensions = 1;
 			XParseGeometry(optarg, &discard, &discard, &opt.min_width, &opt.min_height);
 			break;
 		case '.':
@@ -452,14 +456,7 @@ static void feh_parse_option_array(int argc, char **argv, int finalrun)
 			opt.actions[0] = estrdup(optarg);
 			break;
 		case 'B':
-			if (!strcmp(optarg, "checks"))
-				opt.image_bg = IMAGE_BG_CHECKS;
-			else if (!strcmp(optarg, "white"))
-				opt.image_bg = IMAGE_BG_WHITE;
-			else if (!strcmp(optarg, "black"))
-				opt.image_bg = IMAGE_BG_BLACK;
-			else
-				weprintf("Unknown argument to --image-bg: %s", optarg);
+			opt.image_bg = estrdup(optarg);
 			break;
 		case 'C':
 			D(("adding fontpath %s\n", optarg));
@@ -785,6 +782,13 @@ static void feh_parse_option_array(int argc, char **argv, int finalrun)
 			if (opt.cache_size > 2048)
 				opt.cache_size = 2048;
 			break;
+		case 246:
+			opt.version_sort = 1;
+			break;
+		case 247:
+			opt.offset_flags = XParseGeometry(optarg, &opt.offset_x,
+					&opt.offset_y, (unsigned int *)&discard, (unsigned int *)&discard);
+			break;
 		default:
 			break;
 		}
