@@ -49,7 +49,7 @@ void init_slideshow_mode(void)
 				opt.start_list_at);
 
 	if (!opt.title)
-		opt.title = PACKAGE " [%u of %l] - %f",
+		opt.title = PACKAGE " [%u of %l] - %f";
 
 	mode = "slideshow";
 	for (; l; l = l->next) {
@@ -107,6 +107,10 @@ void cb_reload_timer(void *data)
 			add_file_to_filelist_recursively(l->data, FILELIST_FIRST);
 	else if (!opt.filelistfile && !opt.bgmode)
 		add_file_to_filelist_recursively(".", FILELIST_FIRST);
+
+	if (opt.filelistfile) {
+		filelist = gib_list_cat(filelist, feh_read_filelist(opt.filelistfile));
+	}
 	
 	if (!(filelist_len = gib_list_length(filelist))) {
 		eprintf("No files found to reload.");
@@ -360,16 +364,20 @@ void slideshow_change_image(winwidget winwid, int change, int render)
 			tzoom = winwid->zoom;
 		}
 
-		if ((winwidget_loadimage(winwid, FEH_FILE(current_file->data)))
-		    != 0) {
+		if (winwidget_loadimage(winwid, FEH_FILE(current_file->data))) {
+			int w = gib_imlib_image_get_width(winwid->im);
+			int h = gib_imlib_image_get_height(winwid->im);
+			if (feh_should_ignore_image(winwid->im)) {
+				last = current_file;
+				continue;
+			}
 			winwid->mode = MODE_NORMAL;
 			winwid->file = current_file;
-			if ((winwid->im_w != gib_imlib_image_get_width(winwid->im))
-			    || (winwid->im_h != gib_imlib_image_get_height(winwid->im)))
+			if ((winwid->im_w != w) || (winwid->im_h != h))
 				winwid->had_resize = 1;
 			winwidget_reset_image(winwid);
-			winwid->im_w = gib_imlib_image_get_width(winwid->im);
-			winwid->im_h = gib_imlib_image_get_height(winwid->im);
+			winwid->im_w = w;
+			winwid->im_h = h;
 			if (opt.keep_zoom_vp) {
 				/* put back in: */
 				winwid->mode = tmode;
@@ -460,6 +468,12 @@ char *feh_printf(char *str, feh_file * file, winwidget winwid)
 				if (file)
 					strncat(ret, shell_escape(file->filename), sizeof(ret) - strlen(ret) - 1);
 				break;
+			case 'g':
+				if (winwid) {
+					snprintf(buf, sizeof(buf), "%d,%d", winwid->w, winwid->h);
+					strncat(ret, buf, sizeof(ret) - strlen(ret) - 1);
+				}
+				break;
 			case 'h':
 				if (file && (file->info || !feh_file_info_load(file, NULL))) {
 					snprintf(buf, sizeof(buf), "%d", file->info->height);
@@ -556,6 +570,12 @@ char *feh_printf(char *str, feh_file * file, winwidget winwid)
 					strncat(ret, "1.00", sizeof(ret) - strlen(ret) - 1);
 				}
 				break;
+			case 'Z':
+				if (winwid) {
+					snprintf(buf, sizeof(buf), "%f", winwid->zoom);
+					strncat(ret, buf, sizeof(ret) - strlen(ret) - 1);
+				}
+				break;
 			case '%':
 				strncat(ret, "%", sizeof(ret) - strlen(ret) - 1);
 				break;
